@@ -43,7 +43,9 @@ class GRN_DAT_API Key {
     return buf_;
   }
   UInt32 length() const {
-    return (length_high_ << 4) | (id_and_length_low_ & 0x0F);
+    const UInt32 length = (length_high_ << 4) | (id_and_length_low_ & 0x0F);
+    // 4096 bytes key overflows to 0, so 0 is treated as 4096.
+    return (length == 0) ? MAX_KEY_LENGTH : length;
   }
   UInt32 id() const {
     return id_and_length_low_ >> 4;
