@@ -361,8 +361,6 @@ struct _grn_type {
 
 #define GRN_TYPE_SIZE(type) ((type)->range)
 
-#define GRN_TABLE_SORT_GEO  (0x02 << 0)
-
 #define GRN_OBJ_TMP_OBJECT  0x80000000
 #define GRN_OBJ_TMP_COLUMN  0x40000000
 
@@ -438,11 +436,13 @@ struct _grn_proc {
       grn_operator selector_op;
       bool is_stable;
       grn_applier_func *applier;
+      grn_sorter_func *sorter;
     } function;
     struct {
       grn_command_run_func *run;
     } command;
     struct {
+      grn_tokenizer_build_func *build;
       grn_tokenizer_init_func *init;
       grn_tokenizer_next_func *next;
       grn_tokenizer_fin_func *fin;
@@ -529,24 +529,6 @@ struct _grn_accessor {
   uint32_t reference_count;
 };
 
-typedef enum {
-  GRN_ACCESSOR_VOID = 0,
-  GRN_ACCESSOR_GET_ID,
-  GRN_ACCESSOR_GET_KEY,
-  GRN_ACCESSOR_GET_VALUE,
-  GRN_ACCESSOR_GET_SCORE,
-  GRN_ACCESSOR_GET_NSUBRECS,
-  GRN_ACCESSOR_GET_MAX,
-  GRN_ACCESSOR_GET_MIN,
-  GRN_ACCESSOR_GET_SUM,
-  GRN_ACCESSOR_GET_AVG,
-  GRN_ACCESSOR_GET_MEAN,
-  GRN_ACCESSOR_GET_COLUMN_VALUE,
-  GRN_ACCESSOR_GET_DB_OBJ,
-  GRN_ACCESSOR_LOOKUP,
-  GRN_ACCESSOR_FUNCALL
-} grn_accessor_action;
-
 GRN_API const char *
 grn_obj_get_value_(grn_ctx *ctx, grn_obj *obj, grn_id id, uint32_t *size);
 void
